.. PyEarthData documentation master file, created by
   sphinx-quickstart on Tue Dec  6 10:43:49 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyEarthData's documentation!
=======================================

Python Package for grabbing earth surface and atmosphere data.

Installation
------------
Install latest development version from GitHub
##############################################

.. code-block:: python

   pip install git+git://github.com/ayushanand18/PyEarthData.git


.. toctree::
   :maxdepth: 2
   :caption: Contents:

Contents
--------

.. toctree::
   :maxdepth: 2

   airs
   power

Modules
-------
`airs <airs.html>`__
####################

AIRS module: Get Data directly from AIRS aboard NASA's Aqua Satellite

.. code-block:: python
   
   from pyearthdata import airs

`power <power.html>`__
######################

POWER module: Fetching NASA/POWER CERES/MERRA2 Native Resolution Daily Data

.. code-block:: python
   
   from pyearthdata import power

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
